==> touhoulittlemaid-fabric-1.21.1-0.0.2-neo1.2.2-sources.jar: com/github/tartaricacid/touhoulittlemaid/item/ItemSubstituteJizo.java <==
package com.github.tartaricacid.touhoulittlemaid.item;

import com.github.tartaricacid.touhoulittlemaid.api.event.InteractMaidEvent;
import com.github.tartaricacid.touhoulittlemaid.entity.passive.EntityMaid;
import com.github.tartaricacid.touhoulittlemaid.init.InitItems;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_124;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1836;
import net.minecraft.class_2561;
import javax.annotation.Nullable;
import java.util.List;

public class ItemSubstituteJizo extends class_1792 {
    public ItemSubstituteJizo() {
        super((new class_1793()).method_7889(1));
    }

    public static void onEntityInteract(InteractMaidEvent event) {
        EntityMaid maid = event.getMaid();
        class_1799 stack = event.getStack();
        class_1657 player = event.getPlayer();
        if (maid.method_6171(player) && stack.method_7909() == InitItems.SUBSTITUTE_JIZO && !maid.getIsInvulnerable()) {
            maid.setEntityInvulnerable(true);
            stack.method_7934(1);
            event.setCanceled(true);
        }
    }

    @Override
    public boolean method_7886(class_1799 stack) {
        return true;
    }

    @Override
    @Environment(EnvType.CLIENT)
    public void method_7851(class_1799 stack, @Nullable class_1792.class_9635 worldIn, List<class_2561> tooltip, class_1836 flagIn) {
        tooltip.add(class_2561.method_43471("tooltips.touhou_little_maid.substitute_jizo.desc").method_27692(class_124.field_1080));
    }
}

==> touhoulittlemaid-fabric-1.21.1-0.2.0-neo1.4.2-sources.jar: com/github/tartaricacid/touhoulittlemaid/item/ItemSubstituteJizo.java <==
package com.github.tartaricacid.touhoulittlemaid.item;

import com.github.tartaricacid.touhoulittlemaid.api.event.InteractMaidEvent;
import com.github.tartaricacid.touhoulittlemaid.entity.passive.EntityMaid;
import com.github.tartaricacid.touhoulittlemaid.init.InitItems;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_124;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1814;
import net.minecraft.class_1836;
import net.minecraft.class_2561;
import javax.annotation.Nullable;
import java.util.List;

public class ItemSubstituteJizo extends class_1792 {
    public ItemSubstituteJizo() {
        super((new class_1793()).method_7889(1).method_7894(class_1814.field_8904));
    }

    public static void onEntityInteract(InteractMaidEvent event) {
        EntityMaid maid = event.getMaid();
        class_1799 stack = event.getStack();
        class_1657 player = event.getPlayer();
        if (maid.method_6171(player) && stack.method_7909() == InitItems.SUBSTITUTE_JIZO && !maid.getIsInvulnerable()) {
            maid.setEntityInvulnerable(true);
            stack.method_7934(1);
            event.setCanceled(true);
        }
    }

    @Override
    public boolean method_7886(class_1799 stack) {
        return true;
    }

    @Override
    @Environment(EnvType.CLIENT)
    public void method_7851(class_1799 stack, @Nullable class_1792.class_9635 worldIn, List<class_2561> tooltip, class_1836 flagIn) {
        tooltip.add(class_2561.method_43471("tooltips.touhou_little_maid.substitute_jizo.desc").method_27692(class_124.field_1080));
    }
}
